DEC Technical Character Set - Wikipedia

# DEC Technical Character Set

From Wikipedia, the free encyclopedia
Jump to navigation Jump to search

DEC Technical (TCS) is a 7-bit character set developed by Digital Equipment Corporation.

## Character set[edit]

DEC Technical[1]
| _0 | _1 | _2 | _3 | _4 | _5 | _6 | _7 | _8 | _9 | _A | _B | _C | _D | _E | _F
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
0_ 0 | NUL 0000 | SOH 0001 | STX 0002 | ETX 0003 | EOT 0004 | ENQ 0005 | ACK 0006 | BEL 0007 | BS 0008 | HT 0009 | LF 000A | VT 000B | FF 000C | CR 000D | SO 000E | SI 000F
1_ 16 | DLE 0010 | DC1 0011 | DC2 0012 | DC3 0013 | DC4 0014 | NAK 0015 | SYN 0016 | ETB 0017 | CAN 0018 | EM 0019 | SUB 001A | ESC 001B | FS 001C | GS 001D | RS 001E | US 001F
2_ 32 | SP 0020 | ⎷ 23B7 | ┌ 250C | ─ 2500 | ⌠ 2320 | ⌡ 2321 | │ 2502 | ⎡ 23A1 | ⎣ 23A3 | ⎤ 23A4 | ⎦ 23A6 | ⎛ 239B | ⎝ 239D | ⎞ 239E | ⎠ 23A0 | ⎨ 23A8
3_ 48 | ⎬ 23AC | � | � | � | � | � | � | � |  |  |  |  | ≤ 2264 | ≠ 2260 | ≥ 2265 | ∫ 222B
4_ 64 | ∴ 2234 | ∝ 221D | ∞ 221E | ÷ 00F7 | Δ 0394 | ∇ 2207 | Φ 03A6 | Γ 0393 | ∼ 223C | ≃ 2243 | Θ 0398 | × 00D7 | Λ 039B | ⇔ 21D4 | ⇒ 21D2 | ≡ 2261
5_ 80 | Π 03A0 | Ψ 03A8 |  | Σ 03A3 |  |  | √ 221A | Ω 03A9 | Ξ 039E | Υ 03A5 | ⊂ 2282 | ⊃ 2283 | ∩ 2229 | ∪ 222A | ∧ 2227 | ∨ 2228
6_ 96 | ¬ 00AC | α 03B1 | β 03B2 | χ 03C7 | δ 03B4 | ε 03B5 | φ 03C6 | γ 03B3 | η 03B7 | ι 03B9 | θ 03B8 | κ 03BA | λ 03BB |  | ν 03BD | ∂ 2202
7_ 112 | π 03C0 | ψ 03C8 | ρ 03C1 | σ 03C3 | τ 03C4 |  | ƒ 0192 | ω 03C9 | ξ 03BE | υ 03C5 | ζ 03B6 | ← 2190 | ↑ 2191 | → 2192 | ↓ 2193 | DEL 007F

Letter Number Punctuation Symbol Other Undefined

� Characters from 31 to 37 are intended to assemble a 3x5 uppercase sigma and do not have Unicode equivalents.

## See also[edit]

- DEC Multinational Character Set (MCS)
- DEC National Replacement Character Set (NRCS)
- DEC Special Graphics
- Symbol (typeface) § Encoding

## References[edit]

1. ^
   Williams, Paul Flo (2002) [2000]. "DEC Technical Character Set (TCS)". Retrieved 2017-07-16.

## Further reading[edit]

- Installing and Using the VT420 Video Terminal. Digital Equipment Corporation. EK-VT420-UU-002. Retrieved 2017-07-16. [1]
- VT330/VT340 Programmer Pocket Guide. Digital Equipment Corporation. March 1987. EK-VT3XX-HR-001. Retrieved 2017-07-16.
- LN03 Programmer Reference Manual. Digital Equipment Corporation. November 1985. EK-OLN03-RM-002. Retrieved 2017-07-16. [2]

Retrieved from "https://en.wikipedia.org/w/index.php?title=DEC_Technical_Character_Set&oldid=965211752"
Categories:

- Character sets
- Digital Equipment Corporation